=============================
Markups Supported by MoinMoin
=============================

.. toctree::
   :maxdepth: 1

   moinwiki
   creolewiki
   rest
   docbook
   mediawiki
   markdown

.. _MoinWiki: https://moinmo.in/HelpOnMoinWikiSyntax
.. _WikiCreole: https://www.wikicreole.org/
.. _reStructuredText: https://docutils.sourceforge.io/rst.html
.. _DocBook: https://docbook.org/
.. _MediaWiki: https://www.mediawiki.org/wiki/Help:Formatting
.. _Markdown: https://daringfireball.net/projects/markdown/syntax

In Moin2, you specify the item's markup language when you create a new item.
Currently Moin2 supports `MoinWiki`_, `WikiCreole`_, `reStructuredText`_, `DocBook`_,
`MediaWiki`_ and `Markdown`_ markups.

Moin2 currently provides output converters for MoinWiki, Markdown,
reST, HTML, and DocBook.
When viewing any markup item, the item may be converted to a different markup
language by clicking the Convert link.
